@@ -2,12 +2,13 @@ from collections import OrderedDict
 from datetime import timedelta
 
 from django import forms
+from django.core.validators import MaxValueValidator
 from django.db.models import Q
 from django.db.models.constants import LOOKUP_SEP
 from django.forms.utils import pretty_name
 from django.utils.itercompat import is_iterable
 from django.utils.timezone import now
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from .conf import settings
 from .constants import EMPTY_VALUES
@@ -62,12 +63,14 @@ __all__ = [
 ]
 
 
-class Filter(object):
+class Filter:
     creation_counter = 0
     field_class = forms.Field
 
-    def __init__(self, field_name=None, lookup_expr='exact', *, label=None,
+    def __init__(self, field_name=None, lookup_expr=None, *, label=None,
                  method=None, distinct=False, exclude=False, **kwargs):
+        if lookup_expr is None:
+            lookup_expr = settings.DEFAULT_LOOKUP_EXPR
         self.field_name = field_name
         self.lookup_expr = lookup_expr
         self.label = label
@@ -81,12 +84,6 @@ class Filter(object):
         self.creation_counter = Filter.creation_counter
         Filter.creation_counter += 1
 
-        # TODO: remove assertion in 2.1
-        assert not isinstance(self.lookup_expr, (type(None), list)), \
-            "The `lookup_expr` argument no longer accepts `None` or a list of " \
-            "expressions. Use the `LookupChoiceFilter` instead. See: " \
-            "https://django-filter.readthedocs.io/en/master/guide/migration.html"
-
     def get_method(self, qs):
         """Return filter method based on whether we're excluding
            or simply filtering.
@@ -253,10 +250,13 @@ class MultipleChoiceFilter(Filter):
         return qs.distinct() if self.distinct else qs
 
     def get_filter_predicate(self, v):
+        name = self.field_name
+        if name and self.lookup_expr != settings.DEFAULT_LOOKUP_EXPR:
+            name = LOOKUP_SEP.join([name, self.lookup_expr])
         try:
-            return {self.field_name: getattr(v, self.field.to_field_name)}
+            return {name: getattr(v, self.field.to_field_name)}
         except (AttributeError, TypeError):
-            return {self.field_name: v}
+            return {name: v}
 
 
 class TypedMultipleChoiceFilter(MultipleChoiceFilter):
@@ -278,8 +278,8 @@ class IsoDateTimeFilter(DateTimeFilter):
     For context see:
 
     * https://code.djangoproject.com/ticket/23448
-    * https://github.com/tomchristie/django-rest-framework/issues/1338
-    * https://github.com/alex/django-filter/pull/264
+    * https://github.com/encode/django-rest-framework/issues/1338
+    * https://github.com/carltongibson/django-filter/pull/264
     """
     field_class = IsoDateTimeField
 
@@ -292,7 +292,7 @@ class DurationFilter(Filter):
     field_class = forms.DurationField
 
 
-class QuerySetRequestMixin(object):
+class QuerySetRequestMixin:
     """
     Add callable functionality to filters that support the ``queryset``
     argument. If the ``queryset`` is callable, then it **must** accept the
@@ -358,6 +358,23 @@ class ModelMultipleChoiceFilter(QuerySetRequestMixin, MultipleChoiceFilter):
 class NumberFilter(Filter):
     field_class = forms.DecimalField
 
+    def get_max_validator(self):
+        """
+        Return a MaxValueValidator for the field, or None to disable.
+        """
+        return MaxValueValidator(1e50)
+
+    @property
+    def field(self):
+        if not hasattr(self, '_field'):
+            field = super().field
+            max_validator = self.get_max_validator()
+            if max_validator:
+                field.validators.append(max_validator)
+
+            self._field = field
+        return self._field
+
 
 class NumericRangeFilter(Filter):
     field_class = RangeField
@@ -624,7 +641,7 @@ class LookupChoiceFilter(Filter):
             field = get_model_field(self.model, self.field_name)
             lookups = field.get_lookups()
 
-        return [self.normalize_lookup(l) for l in lookups]
+        return [self.normalize_lookup(lookup) for lookup in lookups]
 
     @property
     def field(self):
@@ -643,10 +660,10 @@ class LookupChoiceFilter(Filter):
 
     def filter(self, qs, lookup):
         if not lookup:
-            return super(LookupChoiceFilter, self).filter(qs, None)
+            return super().filter(qs, None)
 
         self.lookup_expr = lookup.lookup_expr
-        return super(LookupChoiceFilter, self).filter(qs, lookup.value)
+        return super().filter(qs, lookup.value)
 
 
 class OrderingFilter(BaseCSVFilter, ChoiceFilter):
@@ -747,7 +764,7 @@ class OrderingFilter(BaseCSVFilter, ChoiceFilter):
         return [val for pair in zip(ascending, descending) for val in pair]
 
 
-class FilterMethod(object):
+class FilterMethod:
     """
     This helper is used to override Filter.filter() when a 'method' argument
     is passed. It proxies the call to the actual method on the filter's parent.
