@@ -1,68 +1,57 @@
-from __future__ import absolute_import
-from __future__ import unicode_literals
-
 import copy
 from collections import OrderedDict
 
 from django import forms
 from django.db import models
 from django.db.models.constants import LOOKUP_SEP
-from django.db.models.fields.related import ForeignObjectRel
-from django.utils import six
+from django.db.models.fields.related import (
+    ManyToManyRel,
+    ManyToOneRel,
+    OneToOneRel
+)
 
 from .conf import settings
-from .compat import remote_field, remote_queryset
-from .constants import ALL_FIELDS, STRICTNESS, EMPTY_VALUES
-from .filters import (Filter, CharFilter, BooleanFilter, BaseInFilter, BaseRangeFilter,
-                      ChoiceFilter, DateFilter, DateTimeFilter, TimeFilter, ModelChoiceFilter,
-                      ModelMultipleChoiceFilter, NumberFilter, UUIDFilter, DurationFilter)
-from .utils import try_dbfield, get_all_model_fields, get_model_field, resolve_field
+from .constants import ALL_FIELDS
+from .filters import (
+    BaseInFilter,
+    BaseRangeFilter,
+    BooleanFilter,
+    CharFilter,
+    ChoiceFilter,
+    DateFilter,
+    DateTimeFilter,
+    DurationFilter,
+    Filter,
+    ModelChoiceFilter,
+    ModelMultipleChoiceFilter,
+    NumberFilter,
+    TimeFilter,
+    UUIDFilter
+)
+from .utils import (
+    get_all_model_fields,
+    get_model_field,
+    resolve_field,
+    try_dbfield
+)
 
 
-def get_filter_name(field_name, lookup_expr):
+def remote_queryset(field):
     """
-    Combine a field name and lookup expression into a usable filter name.
-    Exact lookups are the implicit default, so "exact" is stripped from the
-    end of the filter name.
+    Get the queryset for the other side of a relationship. This works
+    for both `RelatedField`s and `ForeignObjectRel`s.
     """
-    filter_name = LOOKUP_SEP.join([field_name, lookup_expr])
+    model = field.related_model
 
-    # This also works with transformed exact lookups, such as 'date__exact'
-    _exact = LOOKUP_SEP + 'exact'
-    if filter_name.endswith(_exact):
-        filter_name = filter_name[:-len(_exact)]
+    # Reverse relationships do not have choice limits
+    if not hasattr(field, 'get_limit_choices_to'):
+        return model._default_manager.all()
 
-    return filter_name
+    limit_choices_to = field.get_limit_choices_to()
+    return model._default_manager.complex_filter(limit_choices_to)
 
 
-def _together_valid(form, fieldset):
-    field_presence = [
-        form.cleaned_data.get(field) not in EMPTY_VALUES
-        for field in fieldset
-    ]
-
-    if any(field_presence):
-        return all(field_presence)
-    return True
-
-
-def get_full_clean_override(together):
-    # coerce together to list of pairs
-    if isinstance(together[0], (six.string_types)):
-        together = [together]
-
-    def full_clean(form):
-        super(form.__class__, form).full_clean()
-        message = 'Following fields must be together: %s'
-
-        for each in together:
-            if not _together_valid(form, each):
-                return form.add_error(None, message % ','.join(each))
-
-    return full_clean
-
-
-class FilterSetOptions(object):
+class FilterSetOptions:
     def __init__(self, options=None):
         self.model = getattr(options, 'model', None)
         self.fields = getattr(options, 'fields', None)
@@ -70,21 +59,25 @@ class FilterSetOptions(object):
 
         self.filter_overrides = getattr(options, 'filter_overrides', {})
 
-        self.strict = getattr(options, 'strict', None)
-
         self.form = getattr(options, 'form', forms.Form)
 
-        self.together = getattr(options, 'together', None)
-
 
 class FilterSetMetaclass(type):
     def __new__(cls, name, bases, attrs):
         attrs['declared_filters'] = cls.get_declared_filters(bases, attrs)
 
-        new_class = super(FilterSetMetaclass, cls).__new__(cls, name, bases, attrs)
+        new_class = super().__new__(cls, name, bases, attrs)
         new_class._meta = FilterSetOptions(getattr(new_class, 'Meta', None))
         new_class.base_filters = new_class.get_filters()
 
+        # TODO: remove assertion in 2.1
+        assert not hasattr(new_class, 'filter_for_reverse_field'), (
+            "`%(cls)s.filter_for_reverse_field` has been removed. "
+            "`%(cls)s.filter_for_field` now generates filters for reverse fields. "
+            "See: https://django-filter.readthedocs.io/en/master/guide/migration.html"
+            % {'cls': new_class.__name__}
+        )
+
         return new_class
 
     @classmethod
@@ -95,23 +88,29 @@ class FilterSetMetaclass(type):
             if isinstance(obj, Filter)
         ]
 
-        # Default the `filter.name` to the attribute name on the filterset
+        # Default the `filter.field_name` to the attribute name on the filterset
         for filter_name, f in filters:
-            if getattr(f, 'name', None) is None:
-                f.name = filter_name
+            if getattr(f, 'field_name', None) is None:
+                f.field_name = filter_name
 
         filters.sort(key=lambda x: x[1].creation_counter)
 
-        # merge declared filters from base classes
-        for base in reversed(bases):
-            if hasattr(base, 'declared_filters'):
-                filters = [
-                    (name, f) for name, f
-                    in base.declared_filters.items()
-                    if name not in attrs
-                ] + filters
+        # Ensures a base class field doesn't override cls attrs, and maintains
+        # field precedence when inheriting multiple parents. e.g. if there is a
+        # class C(A, B), and A and B both define 'field', use 'field' from A.
+        known = set(attrs)
 
-        return OrderedDict(filters)
+        def visit(name):
+            known.add(name)
+            return name
+
+        base_filters = [
+            (visit(name), f)
+            for base in bases if hasattr(base, 'declared_filters')
+            for name, f in base.declared_filters.items() if name not in known
+        ]
+
+        return OrderedDict(base_filters + filters)
 
 
 FILTER_FOR_DBFIELD_DEFAULTS = {
@@ -137,18 +136,22 @@ FILTER_FOR_DBFIELD_DEFAULTS = {
     models.GenericIPAddressField:       {'filter_class': CharFilter},
     models.CommaSeparatedIntegerField:  {'filter_class': CharFilter},
     models.UUIDField:                   {'filter_class': UUIDFilter},
+
+    # Forward relationships
     models.OneToOneField: {
         'filter_class': ModelChoiceFilter,
         'extra': lambda f: {
             'queryset': remote_queryset(f),
-            'to_field_name': remote_field(f).field_name,
+            'to_field_name': f.remote_field.field_name,
+            'null_label': settings.NULL_CHOICE_LABEL if f.null else None,
         }
     },
     models.ForeignKey: {
         'filter_class': ModelChoiceFilter,
         'extra': lambda f: {
             'queryset': remote_queryset(f),
-            'to_field_name': remote_field(f).field_name,
+            'to_field_name': f.remote_field.field_name,
+            'null_label': settings.NULL_CHOICE_LABEL if f.null else None,
         }
     },
     models.ManyToManyField: {
@@ -157,77 +160,108 @@ FILTER_FOR_DBFIELD_DEFAULTS = {
             'queryset': remote_queryset(f),
         }
     },
+
+    # Reverse relationships
+    OneToOneRel: {
+        'filter_class': ModelChoiceFilter,
+        'extra': lambda f: {
+            'queryset': remote_queryset(f),
+            'null_label': settings.NULL_CHOICE_LABEL if f.null else None,
+        }
+    },
+    ManyToOneRel: {
+        'filter_class': ModelMultipleChoiceFilter,
+        'extra': lambda f: {
+            'queryset': remote_queryset(f),
+        }
+    },
+    ManyToManyRel: {
+        'filter_class': ModelMultipleChoiceFilter,
+        'extra': lambda f: {
+            'queryset': remote_queryset(f),
+        }
+    },
 }
 
 
-class BaseFilterSet(object):
+class BaseFilterSet:
     FILTER_DEFAULTS = FILTER_FOR_DBFIELD_DEFAULTS
 
-    def __init__(self, data=None, queryset=None, prefix=None, strict=None, request=None):
-        self.is_bound = data is not None
-        self.data = data or {}
+    def __init__(self, data=None, queryset=None, *, request=None, prefix=None):
         if queryset is None:
             queryset = self._meta.model._default_manager.all()
+        model = queryset.model
+
+        self.is_bound = data is not None
+        self.data = data or {}
         self.queryset = queryset
-        self.form_prefix = prefix
-
-        # What to do on on validation errors
-        # Fallback to meta, then settings strictness
-        if strict is None:
-            strict = self._meta.strict
-        if strict is None:
-            strict = settings.STRICTNESS
-
-        # transform legacy values
-        self.strict = STRICTNESS._LEGACY.get(strict, strict)
-
         self.request = request
+        self.form_prefix = prefix
 
         self.filters = copy.deepcopy(self.base_filters)
 
+        # propagate the model and filterset to the filters
         for filter_ in self.filters.values():
-            # propagate the model and filterset to the filters
-            filter_.model = self._meta.model
+            filter_.model = model
             filter_.parent = self
 
+    def is_valid(self):
+        """
+        Return True if the underlying form has no errors, or False otherwise.
+        """
+        return self.is_bound and self.form.is_valid()
+
+    @property
+    def errors(self):
+        """
+        Return an ErrorDict for the data provided for the underlying form.
+        """
+        return self.form.errors
+
+    def filter_queryset(self, queryset):
+        """
+        Filter the queryset with the underlying form's `cleaned_data`. You must
+        call `is_valid()` or `errors` before calling this method.
+
+        This method should be overridden if additional filtering needs to be
+        applied to the queryset before it is cached.
+        """
+        for name, value in self.form.cleaned_data.items():
+            queryset = self.filters[name].filter(queryset, value)
+            assert isinstance(queryset, models.QuerySet), \
+                "Expected '%s.%s' to return a QuerySet, but got a %s instead." \
+                % (type(self).__name__, name, type(queryset).__name__)
+        return queryset
+
     @property
     def qs(self):
         if not hasattr(self, '_qs'):
-            if not self.is_bound:
-                self._qs = self.queryset.all()
-                return self._qs
-
-            if not self.form.is_valid():
-                if self.strict == STRICTNESS.RAISE_VALIDATION_ERROR:
-                    raise forms.ValidationError(self.form.errors)
-                elif self.strict == STRICTNESS.RETURN_NO_RESULTS:
-                    self._qs = self.queryset.none()
-                    return self._qs
-                # else STRICTNESS.IGNORE...  ignoring
-
-            # start with all the results and filter from there
             qs = self.queryset.all()
-            for name, filter_ in six.iteritems(self.filters):
-                value = self.form.cleaned_data.get(name)
-
-                if value is not None:  # valid & clean data
-                    qs = filter_.filter(qs, value)
-
+            if self.is_bound:
+                # ensure form validation before filtering
+                self.errors
+                qs = self.filter_queryset(qs)
             self._qs = qs
-
         return self._qs
 
+    def get_form_class(self):
+        """
+        Returns a django Form suitable of validating the filterset data.
+
+        This method should be overridden if the form class needs to be
+        customized relative to the filterset instance.
+        """
+        fields = OrderedDict([
+            (name, filter_.field)
+            for name, filter_ in self.filters.items()])
+
+        return type(str('%sForm' % self.__class__.__name__),
+                    (self._meta.form,), fields)
+
     @property
     def form(self):
         if not hasattr(self, '_form'):
-            fields = OrderedDict([
-                (name, filter_.field)
-                for name, filter_ in six.iteritems(self.filters)])
-
-            Form = type(str('%sForm' % self.__class__.__name__),
-                        (self._meta.form,), fields)
-            if self._meta.together:
-                Form.full_clean = get_full_clean_override(self._meta.together)
+            Form = self.get_form_class()
             if self.is_bound:
                 self._form = Form(self.data, prefix=self.form_prefix)
             else:
@@ -260,12 +294,28 @@ class BaseFilterSet(object):
         # Remove excluded fields
         exclude = exclude or []
         if not isinstance(fields, dict):
-            fields = [(f, ['exact']) for f in fields if f not in exclude]
+            fields = [(f, [settings.DEFAULT_LOOKUP_EXPR]) for f in fields if f not in exclude]
         else:
             fields = [(f, lookups) for f, lookups in fields.items() if f not in exclude]
 
         return OrderedDict(fields)
 
+    @classmethod
+    def get_filter_name(cls, field_name, lookup_expr):
+        """
+        Combine a field name and lookup expression into a usable filter name.
+        Exact lookups are the implicit default, so "exact" is stripped from the
+        end of the filter name.
+        """
+        filter_name = LOOKUP_SEP.join([field_name, lookup_expr])
+
+        # This also works with transformed exact lookups, such as 'date__exact'
+        _default_expr = LOOKUP_SEP + settings.DEFAULT_LOOKUP_EXPR
+        if filter_name.endswith(_default_expr):
+            filter_name = filter_name[:-len(_default_expr)]
+
+        return filter_name
+
     @classmethod
     def get_filters(cls):
         """
@@ -289,13 +339,8 @@ class BaseFilterSet(object):
             if field is None:
                 undefined.append(field_name)
 
-            # ForeignObjectRel does not support non-exact lookups
-            if isinstance(field, ForeignObjectRel):
-                filters[field_name] = cls.filter_for_reverse_field(field, field_name)
-                continue
-
             for lookup_expr in lookups:
-                filter_name = get_filter_name(field_name, lookup_expr)
+                filter_name = cls.get_filter_name(field_name, lookup_expr)
 
                 # If the filter is explicitly declared on the class, skip generation
                 if filter_name in cls.declared_filters:
@@ -305,12 +350,14 @@ class BaseFilterSet(object):
                 if field is not None:
                     filters[filter_name] = cls.filter_for_field(field, field_name, lookup_expr)
 
-        # filter out declared filters
-        undefined = [f for f in undefined if f not in cls.declared_filters]
+        # Allow Meta.fields to contain declared filters *only* when a list/tuple
+        if isinstance(cls._meta.fields, (list, tuple)):
+            undefined = [f for f in undefined if f not in cls.declared_filters]
+
         if undefined:
             raise TypeError(
-                "'Meta.fields' contains fields that are not defined on this FilterSet: "
-                "%s" % ', '.join(undefined)
+                "'Meta.fields' must not contain non-model field names: %s"
+                % ', '.join(undefined)
             )
 
         # Add in declared filters. This is necessary since we don't enforce adding
@@ -319,61 +366,51 @@ class BaseFilterSet(object):
         return filters
 
     @classmethod
-    def filter_for_field(cls, f, name, lookup_expr='exact'):
-        f, lookup_type = resolve_field(f, lookup_expr)
+    def filter_for_field(cls, field, field_name, lookup_expr=None):
+        if lookup_expr is None:
+            lookup_expr = settings.DEFAULT_LOOKUP_EXPR
+        field, lookup_type = resolve_field(field, lookup_expr)
 
         default = {
-            'name': name,
+            'field_name': field_name,
             'lookup_expr': lookup_expr,
         }
 
-        filter_class, params = cls.filter_for_lookup(f, lookup_type)
+        filter_class, params = cls.filter_for_lookup(field, lookup_type)
         default.update(params)
 
         assert filter_class is not None, (
             "%s resolved field '%s' with '%s' lookup to an unrecognized field "
             "type %s. Try adding an override to 'Meta.filter_overrides'. See: "
-            "https://django-filter.readthedocs.io/en/develop/ref/filterset.html#customise-filter-generation-with-filter-overrides"
-        ) % (cls.__name__, name, lookup_expr, f.__class__.__name__)
+            "https://django-filter.readthedocs.io/en/master/ref/filterset.html"
+            "#customise-filter-generation-with-filter-overrides"
+        ) % (cls.__name__, field_name, lookup_expr, field.__class__.__name__)
 
         return filter_class(**default)
 
     @classmethod
-    def filter_for_reverse_field(cls, f, name):
-        rel = remote_field(f.field)
-        queryset = f.field.model._default_manager.all()
-        default = {
-            'name': name,
-            'queryset': queryset,
-        }
-        if rel.multiple:
-            return ModelMultipleChoiceFilter(**default)
-        else:
-            return ModelChoiceFilter(**default)
-
-    @classmethod
-    def filter_for_lookup(cls, f, lookup_type):
+    def filter_for_lookup(cls, field, lookup_type):
         DEFAULTS = dict(cls.FILTER_DEFAULTS)
         if hasattr(cls, '_meta'):
             DEFAULTS.update(cls._meta.filter_overrides)
 
-        data = try_dbfield(DEFAULTS.get, f.__class__) or {}
+        data = try_dbfield(DEFAULTS.get, field.__class__) or {}
         filter_class = data.get('filter_class')
-        params = data.get('extra', lambda f: {})(f)
+        params = data.get('extra', lambda field: {})(field)
 
         # if there is no filter class, exit early
         if not filter_class:
             return None, {}
 
         # perform lookup specific checks
-        if lookup_type == 'exact' and f.choices:
-            return ChoiceFilter, {'choices': f.choices}
+        if lookup_type == 'exact' and getattr(field, 'choices', None):
+            return ChoiceFilter, {'choices': field.choices}
 
         if lookup_type == 'isnull':
             data = try_dbfield(DEFAULTS.get, models.BooleanField)
 
             filter_class = data.get('filter_class')
-            params = data.get('extra', lambda f: {})(f)
+            params = data.get('extra', lambda field: {})(field)
             return filter_class, params
 
         if lookup_type == 'in':
@@ -422,7 +459,7 @@ class BaseFilterSet(object):
         return str('%s%sFilter' % (type_name, lookup_name))
 
 
-class FilterSet(six.with_metaclass(FilterSetMetaclass, BaseFilterSet)):
+class FilterSet(BaseFilterSet, metaclass=FilterSetMetaclass):
     pass
 
 
