@@ -3,8 +3,8 @@ import warnings
 from django.template import loader
 from django.utils.deprecation import RenameMethodsBase
 
-from . import filters, filterset
 from .. import compat, utils
+from . import filters, filterset
 
 
 # TODO: remove metaclass in 2.1
@@ -138,3 +138,33 @@ class DjangoFilterBackend(metaclass=RenameAttributes):
                 schema=self.get_coreschema_field(field)
             ) for field_name, field in filterset_class.base_filters.items()
         ]
+
+    def get_schema_operation_parameters(self, view):
+        try:
+            queryset = view.get_queryset()
+        except Exception:
+            queryset = None
+            warnings.warn(
+                "{} is not compatible with schema generation".format(view.__class__)
+            )
+
+        filterset_class = self.get_filterset_class(view, queryset)
+
+        if not filterset_class:
+            return []
+
+        parameters = []
+        for field_name, field in filterset_class.base_filters.items():
+            parameter = {
+                'name': field_name,
+                'required': field.extra['required'],
+                'in': 'query',
+                'description': field.label if field.label is not None else field_name,
+                'schema': {
+                    'type': 'string',
+                },
+            }
+            if field.extra and 'choices' in field.extra:
+                parameter['schema']['enum'] = [c[0] for c in field.extra['choices']]
+            parameters.append(parameter)
+        return parameters
