@@ -1,18 +1,16 @@
 import warnings
 from collections import OrderedDict
 
-import django
 from django.conf import settings
-from django.core.exceptions import FieldError
+from django.core.exceptions import FieldDoesNotExist, FieldError
 from django.db import models
 from django.db.models.constants import LOOKUP_SEP
 from django.db.models.expressions import Expression
-from django.db.models.fields import FieldDoesNotExist
 from django.db.models.fields.related import ForeignObjectRel, RelatedField
 from django.utils import timezone
-from django.utils.encoding import force_text
+from django.utils.encoding import force_str
 from django.utils.text import capfirst
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 
 from .exceptions import FieldLookupError
 
@@ -184,7 +182,7 @@ def resolve_field(model_field, lookup_expr):
     This method is based on django.db.models.sql.query.Query.build_lookup
 
     For more info on the lookup API:
-    https://docs.djangoproject.com/en/1.9/ref/models/lookups/
+    https://docs.djangoproject.com/en/stable/ref/models/lookups/
 
     """
     query = model_field.model._default_manager.all().query
@@ -197,9 +195,6 @@ def resolve_field(model_field, lookup_expr):
         while lookups:
             name = lookups[0]
             args = (lhs, name)
-            if django.VERSION < (2, 0):
-                # rest_of_lookups was removed in Django 2.0
-                args += (lookups,)
             # If there is just one part left, try first get_lookup() so
             # that if the lhs supports both transform and lookup for the
             # name, then lookup will be picked.
@@ -253,7 +248,7 @@ def verbose_field_name(model, field_name):
             else:
                 return '[invalid name]'
         else:
-            names.append(force_text(part.verbose_name))
+            names.append(force_str(part.verbose_name))
 
     return ' '.join(names)
 
@@ -278,7 +273,7 @@ def verbose_lookup_expr(lookup_expr):
 
     VERBOSE_LOOKUPS = app_settings.VERBOSE_LOOKUPS or {}
     lookups = [
-        force_text(VERBOSE_LOOKUPS.get(lookup, _(lookup)))
+        force_str(VERBOSE_LOOKUPS.get(lookup, _(lookup)))
         for lookup in lookup_expr.split(LOOKUP_SEP)
     ]
 
@@ -302,7 +297,7 @@ def label_for_filter(model, field_name, lookup_expr, exclude=False):
     if isinstance(lookup_expr, str):
         verbose_expression += [verbose_lookup_expr(lookup_expr)]
 
-    verbose_expression = [force_text(part) for part in verbose_expression if part]
+    verbose_expression = [force_str(part) for part in verbose_expression if part]
     verbose_expression = capfirst(' '.join(verbose_expression))
 
     return verbose_expression
@@ -314,7 +309,7 @@ def translate_validation(error_dict):
     """
     # it's necessary to lazily import the exception, as it can otherwise create
     # an import loop when importing django_filters inside the project settings.
-    from rest_framework.exceptions import ValidationError, ErrorDetail
+    from rest_framework.exceptions import ErrorDetail, ValidationError
 
     exc = OrderedDict(
         (key, [ErrorDetail(e.message % (e.params or ()), code=e.code)
