@@ -47,7 +47,7 @@ class User(models.Model):
     status = models.IntegerField(choices=STATUS_CHOICES, default=0)
 
     is_active = models.BooleanField(default=False)
-    is_employed = models.NullBooleanField(default=False)
+    is_employed = models.BooleanField(null=True, default=False)
 
     favorite_books = models.ManyToManyField('Book', related_name='lovers')
 
