@@ -25,6 +25,8 @@ ROOT_URLCONF = 'tests.urls'
 
 USE_TZ = True
 
+TIME_ZONE = 'UTC'
+
 SECRET_KEY = 'foobar'
 
 TEMPLATES = [{
@@ -36,6 +38,10 @@ TEMPLATES = [{
 STATIC_URL = '/static/'
 
 
+# XMLTestRunner output
+TEST_OUTPUT_DIR = '.xmlcoverage'
+
+
 # help verify that DEFAULTS is importable from conf.
 def FILTERS_VERBOSE_LOOKUPS():
     return DEFAULTS['VERBOSE_LOOKUPS']
