@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 import inspect
 import mock
 from collections import OrderedDict
@@ -7,7 +6,7 @@ from datetime import date, datetime, time, timedelta
 from django import forms
 from django.test import TestCase, override_settings
 from django.utils import translation
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 
 from django_filters import filters, widgets
 from django_filters.fields import (
@@ -95,19 +94,6 @@ class FilterTests(TestCase):
         field = f.field
         self.assertIsInstance(field, forms.Field)
 
-    def test_field_with_lookup_types_removal(self):
-        msg = (
-            "The `lookup_expr` argument no longer accepts `None` or a list of "
-            "expressions. Use the `LookupChoiceFilter` instead. See: "
-            "https://django-filter.readthedocs.io/en/master/guide/migration.html"
-        )
-
-        with self.assertRaisesMessage(AssertionError, msg):
-            Filter(lookup_expr=[])
-
-        with self.assertRaisesMessage(AssertionError, msg):
-            Filter(lookup_expr=None)
-
     def test_field_params(self):
         with mock.patch.object(Filter, 'field_class',
                                spec=['__call__']) as mocked:
@@ -389,6 +375,11 @@ class MultipleChoiceFilterTests(TestCase):
         f = MultipleChoiceFilter(conjoined=True)
         self.assertTrue(f.conjoined)
 
+    def test_is_noop_false(self):
+        f = MultipleChoiceFilter(required=False)
+        f.always_filter = False
+        self.assertFalse(f.is_noop(None, ['value']))
+
     def test_filtering(self):
         qs = mock.Mock(spec=['filter'])
         f = MultipleChoiceFilter(field_name='somefield')
@@ -419,6 +410,21 @@ class MultipleChoiceFilterTests(TestCase):
             qs.exclude.assert_called_once_with(mockQ1.__ior__.return_value)
             qs.exclude.return_value.distinct.assert_called_once_with()
 
+    def test_filtering_with_lookup_expr(self):
+        qs = mock.Mock(spec=['filter'])
+        f = MultipleChoiceFilter(field_name='somefield', lookup_expr='icontains')
+        with mock.patch('django_filters.filters.Q') as mockQclass:
+            mockQ1, mockQ2 = mock.MagicMock(), mock.MagicMock()
+            mockQclass.side_effect = [mockQ1, mockQ2]
+
+            f.filter(qs, ['value'])
+
+            self.assertEqual(mockQclass.call_args_list,
+                             [mock.call(), mock.call(somefield__icontains='value')])
+            mockQ1.__ior__.assert_called_once_with(mockQ2)
+            qs.filter.assert_called_once_with(mockQ1.__ior__.return_value)
+            qs.filter.return_value.distinct.assert_called_once_with()
+
     def test_filtering_on_required_skipped_when_len_of_value_is_len_of_field_choices(self):
         qs = mock.Mock(spec=[])
         f = MultipleChoiceFilter(field_name='somefield', required=True)
@@ -1571,6 +1577,6 @@ class OrderingFilterTests(TestCase):
             ])
 
     def test_help_text(self):
-        # regression test for #756 - the ususal CSV help_text is not relevant to ordering filters.
+        # regression test for #756 - the usual CSV help_text is not relevant to ordering filters.
         self.assertEqual(OrderingFilter().field.help_text, '')
         self.assertEqual(OrderingFilter(help_text='a').field.help_text, 'a')
